References — CUBmods 0.0.1 documentation

Skip to main content
`Ctrl`+`K`

# References

[CP17]

Stefania Capecchi and Domenico Piccolo. Dealing with heterogeneity in ordinal responses. Quality & Quantity, 51:2375–2393, 2017.

[CSDI+21]

Giovanni Cerulli, R Simone, Francesca Di Iorio, D Piccolo, CF Baum, and others. The Stata module for CUB models for rating data analysis. In London Stata Conference 2021, number 16. Stata Users Group, 2021.

[CIP09]

Marcella Corduas, Maria Iannario, and Domenico Piccolo. A class of statistical models for evaluating services and performances. In Statistical methods for the evaluation of educational services and quality of products, pages 99–117. Springer, 2009.

[DEliaP+05]

A D'Elia, Domenico Piccolo, and others. The moment estimator for the IHG distribution. In S. Co. Modelli complessi e metodi computazionali intensivi per la stima e la previsione, pages 245–250. CLEUP, 2005.

[DEliaP05]

Angela D'Elia and Domenico Piccolo. A mixture model for preferences data analysis. Computational Statistics & Data Analysis, 49(3):917–934, 2005.

[DElia03]

Angela D’Elia. Modelling ranks using the inverse hypergeometric distribution. Statistical modelling, 3(1):65–78, 2003.

[Ian12a]

Maria Iannario. Cube models for interpreting ordered categorical data with overdispersion. Quaderni di statistica, 14:137–140, 2012.

[Ian12b]

Maria Iannario. Modelling shelter choices in a class of mixture models for ordinal responses. Statistical Methods & Applications, 21:1–22, 2012.

[Ian14]

Maria Iannario. Modelling uncertainty and overdispersion in ordinal data. Communications in Statistics-Theory and Methods, 43(4):771–786, 2014.

[IP09]

Maria Iannario and Domenico Piccolo. A program in R for CUB models inference. Available via Internet, URL http://www. dipstat. unina. it/CUBmodels/, Version, 2009.

[IP10]

Maria Iannario and Domenico Piccolo. A new statistical model for the analysis of customer satisfaction. Quality Technology & Quantitative Management, 7(2):149–168, 2010.

[IP+14]

Maria Iannario, Domenico Piccolo, and others. Inference for CUB models: a program in R. Statistica & Applicazioni, 12(2):177–204, 2014.

[IPSMaintainer22]

Maria Iannario, Domenico Piccolo, and Rosaria Simone (Maintainer). Package ‘CUB’. CRAN, 2022.

[Pic03]

Domenico Piccolo. On the moments of a mixture of uniform and shifted binomial random variables. Quaderni di Statistica, 5(1):85–104, 2003.

[Pic06]

Domenico Piccolo. Observed information matrix for MUB models. Quaderni di Statistica, 8(1):33–78, 2006.

[Pic15]

Domenico Piccolo. Inferential issues on cube models with covariates. Communications in Statistics-Theory and Methods, 44(23):5023–5036, 2015.

[PS19]

Domenico Piccolo and Rosaria Simone. The class of CUB models: statistical foundations, inferential issues and empirical evidence (with discussion and rejoinder). Statistical Methods & Applications, 28:389–493, 2019.

[Pie24]

Massimo Pierini. Modelli della classe CUB in python. Universitas Mercatorum, Rome, IT, pages 1–172, June 2024. (Bachelor's thesis L-41).

[PL20]

W Stephen Pittard and Shuzhao Li. The essential toolbox of data science: python, R, git, and docker. Computational Methods and Data Analysis for Metabolomics, pages 265–311, 2020.

[Sim22]

Rosaria Simone. On finite mixtures of Discretized Beta model for ordered responses. TEST, 31(3):828–855, 2022.

[SDIL19]

Rosaria Simone, Francesca Di Iorio, and Riccardo Lucchetti. CUB for gretl. GNU Regression, Econometrics and Time Series Library, pages 147, 2019.

[ST18]

Rosaria Simone and Gerhard Tutz. Modelling uncertainty and response styles in ordinal data. Statistica Neerlandica, 72(3):224–245, 2018.